@@ -18,13 +18,14 @@ from oslo_log import log as logging
 from oslo_service import periodic_task
 
 from trove.common import cfg
+from trove.common import constants
 from trove.common import exception
-from trove.common import utils
 from trove.common.notification import EndNotification
-from trove.guestagent import guest_log
+from trove.common import utils
 from trove.guestagent.common import operating_system
 from trove.guestagent.datastore import manager
 from trove.guestagent.datastore.postgres import service
+from trove.guestagent import guest_log
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
@@ -212,8 +213,8 @@ class PostgresManager(manager.Manager):
                 '/var/lib/postgresql/data': {
                     'bind': '/var/lib/postgresql/data', 'mode': 'rw'
                 },
-                "/var/run/postgresql": {"bind": "/var/run/postgresql",
-                                        "mode": "ro"},
+                constants.POSTGRESQL_HOST_SOCKET_PATH:
+                    {"bind": "/var/run/postgresql", "mode": "ro"},
             }
             extra_params = f"--pg-wal-archive-dir {service.WAL_ARCHIVE_DIR}"
 
